@@ -1,7 +1,9 @@
 #pragma once
 
-#include "../defines.hpp"
 #include <deque>
+#include <array>
+#include <vector>
+#include "Vector2D.hpp"
 
 constexpr int   BAKEDPOINTS    = 255;
 constexpr float INVBAKEDPOINTS = 1.f / BAKEDPOINTS;
