@@ -1,6 +1,6 @@
 #pragma once
 
-#include <math.h>
+#include <cmath>
 
 class Vector2D {
   public:
@@ -42,10 +42,20 @@ class Vector2D {
     Vector2D operator/(const Vector2D& a) const {
         return Vector2D(this->x / a.x, this->y / a.y);
     }
-    
-    double   distance(const Vector2D& other);
 
-    Vector2D clamp(const Vector2D& min, const Vector2D& max = Vector2D());
+    bool operator>(const Vector2D& a) const {
+        return this->x > a.x && this->y > a.y;
+    }
 
-    Vector2D floor();
+    bool operator<(const Vector2D& a) const {
+        return this->x < a.x && this->y < a.y;
+    }
+
+    double   distance(const Vector2D& other) const;
+
+    Vector2D clamp(const Vector2D& min, const Vector2D& max = Vector2D()) const;
+
+    Vector2D floor() const;
+
+    bool     inTriangle(const Vector2D& p1, const Vector2D& p2, const Vector2D& p3) const;
 };
