@@ -15,14 +15,11 @@ class CEventManager {
   public:
     CEventManager();
 
-    void        postEvent(const SHyprIPCEvent event, bool force = false);
+    void        postEvent(const SHyprIPCEvent event);
 
     void        startThread();
 
-    bool        m_bIgnoreEvents = false;
-
     std::thread m_tThread;
-
   private:
     void                                         flushEvents();
 
@@ -32,4 +29,4 @@ class CEventManager {
     std::deque<std::pair<int, wl_event_source*>> m_dAcceptedSocketFDs;
 };
 
-inline std::unique_ptr<CEventManager> g_pEventManager;
\ No newline at end of file
+inline std::unique_ptr<CEventManager> g_pEventManager;
