@@ -22,6 +22,7 @@ struct SKeybind {
     bool        repeat       = false;
     bool        mouse        = false;
     bool        nonConsuming = false;
+    bool        transparent  = false;
 
     // DO NOT INITIALIZE
     bool shadowed = false;
@@ -67,8 +68,6 @@ class CKeybindManager {
 
     inline static std::string m_szCurrentSelectedSubmap = "";
 
-    xkb_keysym_t              m_kHeldBack = 0;
-
     SKeybind*                 m_pActiveKeybind = nullptr;
 
     uint32_t                  m_uTimeLastMs    = 0;
