@@ -2,6 +2,7 @@
 
 #include "../defines.hpp"
 #include "../Window.hpp"
+#include <optional>
 
 class CHyprXWaylandManager {
   public:
@@ -25,6 +26,7 @@ class CHyprXWaylandManager {
     void          moveXWaylandWindow(CWindow*, const Vector2D&);
     void          checkBorders(CWindow*);
     Vector2D      getMaxSizeForWindow(CWindow*);
+    Vector2D      xwaylandToWaylandCoords(const Vector2D&);
 };
 
 inline std::unique_ptr<CHyprXWaylandManager> g_pXWaylandManager;
\ No newline at end of file
