@@ -30,6 +30,7 @@ struct wlr_wl_backend {
 
 	/* remote state */
 	struct wl_display *remote_display;
+	bool own_remote_display;
 	struct wl_event_source *remote_display_src;
 	struct wl_registry *registry;
 	struct wl_compositor *compositor;
@@ -83,12 +84,14 @@ struct wlr_wl_output {
 	struct wl_list link;
 
 	struct wl_surface *surface;
+	bool own_surface;
 	struct wl_callback *frame_callback;
 	struct xdg_surface *xdg_surface;
 	struct xdg_toplevel *xdg_toplevel;
 	struct zxdg_toplevel_decoration_v1 *zxdg_toplevel_decoration_v1;
 	struct wl_list presentation_feedbacks;
 
+	bool configured;
 	uint32_t enter_serial;
 
 	struct {
@@ -153,6 +156,8 @@ struct wlr_wl_seat {
 };
 
 struct wlr_wl_backend *get_wl_backend_from_backend(struct wlr_backend *backend);
+struct wlr_wl_output *get_wl_output_from_surface(struct wlr_wl_backend *wl,
+	struct wl_surface *surface);
 void update_wl_output_cursor(struct wlr_wl_output *output);
 
 void init_seat_keyboard(struct wlr_wl_seat *seat);
