@@ -14,6 +14,7 @@
 #include <time.h>
 #include <wayland-server-protocol.h>
 #include <wayland-util.h>
+#include <wlr/render/wlr_renderer.h>
 #include <wlr/types/wlr_buffer.h>
 #include <wlr/util/addon.h>
 
@@ -39,16 +40,12 @@ struct wlr_output_cursor {
 	bool enabled;
 	bool visible;
 	uint32_t width, height;
+	struct wlr_fbox src_box;
+	enum wl_output_transform transform;
 	int32_t hotspot_x, hotspot_y;
-	struct wl_list link;
-
-	// only when using a software cursor without a surface
 	struct wlr_texture *texture;
-
-	// only when using a cursor surface
-	struct wlr_surface *surface;
-	struct wl_listener surface_commit;
-	struct wl_listener surface_destroy;
+	bool own_texture;
+	struct wl_list link;
 };
 
 enum wlr_output_adaptive_sync_status {
@@ -91,10 +88,8 @@ struct wlr_output_state {
 	uint32_t render_format;
 	enum wl_output_subpixel subpixel;
 
-	// only valid if WLR_OUTPUT_STATE_BUFFER
 	struct wlr_buffer *buffer;
 
-	// only valid if WLR_OUTPUT_STATE_MODE
 	enum wlr_output_state_mode_type mode_type;
 	struct wlr_output_mode *mode;
 	struct {
@@ -102,11 +97,9 @@ struct wlr_output_state {
 		int32_t refresh; // mHz, may be zero
 	} custom_mode;
 
-	// only valid if WLR_OUTPUT_STATE_GAMMA_LUT
 	uint16_t *gamma_lut;
 	size_t gamma_lut_size;
 
-	// only valid if WLR_OUTPUT_STATE_LAYERS
 	struct wlr_output_layer_state *layers;
 	size_t layers_len;
 };
@@ -169,20 +162,21 @@ struct wlr_output {
 		struct wl_signal frame;
 		// Emitted when software cursors or backend-specific logic damage the
 		// output
-		struct wl_signal damage; // wlr_output_event_damage
+		struct wl_signal damage; // struct wlr_output_event_damage
 		// Emitted when a new frame needs to be committed (because of
 		// backend-specific logic)
 		struct wl_signal needs_frame;
 		// Emitted right before commit
-		struct wl_signal precommit; // wlr_output_event_precommit
+		struct wl_signal precommit; // struct wlr_output_event_precommit
 		// Emitted right after commit
-		struct wl_signal commit; // wlr_output_event_commit
-		// Emitted right after the buffer has been presented to the user
-		struct wl_signal present; // wlr_output_event_present
+		struct wl_signal commit; // struct wlr_output_event_commit
+		// Emitted right after a commit has been presented to the user for
+		// enabled outputs
+		struct wl_signal present; // struct wlr_output_event_present
 		// Emitted after a client bound the wl_output global
-		struct wl_signal bind; // wlr_output_event_bind
+		struct wl_signal bind; // struct wlr_output_event_bind
 		struct wl_signal description;
-		struct wl_signal request_state;
+		struct wl_signal request_state; // struct wlr_output_state
 		struct wl_signal destroy;
 	} events;
 
@@ -465,8 +459,23 @@ bool wlr_output_commit(struct wlr_output *output);
  * Discard the pending output state.
  */
 void wlr_output_rollback(struct wlr_output *output);
+
+/**
+ * Test whether this output state would be accepted by the backend. If this
+ * function returns true, wlr_output_commit_state() will only fail due to a
+ * runtime error. This function does not change the current state of the
+ * output.
+ */
 bool wlr_output_test_state(struct wlr_output *output,
 	const struct wlr_output_state *state);
+/**
+ * Attempts to apply the state to this output. This function may fail for any
+ * reason and return false. If failed, none of the state would have been applied,
+ * this function is atomic. If the commit succeeded, true is returned.
+ *
+ * Note: wlr_output_state_finish() would typically be called after the state
+ * has been committed.
+ */
 bool wlr_output_commit_state(struct wlr_output *output,
 	const struct wlr_output_state *state);
 /**
@@ -543,39 +552,156 @@ bool wlr_output_is_direct_scanout_allowed(struct wlr_output *output);
 
 
 struct wlr_output_cursor *wlr_output_cursor_create(struct wlr_output *output);
-/**
- * Sets the cursor image. The image must be already scaled for the output.
- */
-bool wlr_output_cursor_set_image(struct wlr_output_cursor *cursor,
-	const uint8_t *pixels, int32_t stride, uint32_t width, uint32_t height,
-	int32_t hotspot_x, int32_t hotspot_y);
-void wlr_output_cursor_set_surface(struct wlr_output_cursor *cursor,
-	struct wlr_surface *surface, int32_t hotspot_x, int32_t hotspot_y);
 bool wlr_output_cursor_set_buffer(struct wlr_output_cursor *cursor,
 	struct wlr_buffer *buffer, int32_t hotspot_x, int32_t hotspot_y);
 bool wlr_output_cursor_move(struct wlr_output_cursor *cursor,
 	double x, double y);
 void wlr_output_cursor_destroy(struct wlr_output_cursor *cursor);
 
-
+/**
+ * Initialize an output state.
+ */
+void wlr_output_state_init(struct wlr_output_state *state);
+/**
+ * Releases all resources associated with an output state.
+ */
 void wlr_output_state_finish(struct wlr_output_state *state);
+/**
+ * Enables or disables an output. A disabled output is turned off and doesn't
+ * emit `frame` events.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_enabled(struct wlr_output_state *state,
 	bool enabled);
+/**
+ * Sets the output mode of an output. An output mode will specify the resolution
+ * and refresh rate, among other things.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_mode(struct wlr_output_state *state,
 	struct wlr_output_mode *mode);
+/**
+ * Sets a custom output mode for an output. See wlr_output_state_set_mode()
+ * for details.
+ *
+ * When the output advertises fixed modes, custom modes are not guaranteed to
+ * work correctly, they may result in visual artifacts. If a suitable fixed mode
+ * is available, compositors should prefer it and use wlr_output_state_set_mode()
+ * instead of custom modes.
+ *
+ * Setting `refresh` to zero lets the backend pick a preferred value. The
+ * output needs to be enabled.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_custom_mode(struct wlr_output_state *state,
 	int32_t width, int32_t height, int32_t refresh);
+/**
+ * Sets the scale of an output. The scale is used to increase the size of UI
+ * elements to aid users who use high DPI outputs.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_scale(struct wlr_output_state *state, float scale);
+/**
+ * Sets the transform of an output. The transform is used to rotate or flip
+ * the contents of the screen.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_transform(struct wlr_output_state *state,
 	enum wl_output_transform transform);
+/**
+ * Enables or disable adaptive sync for an output (ie. variable refresh rate).
+ * Compositors can inspect `wlr_output.adaptive_sync_status` to query the
+ * effective status. Backends that don't support adaptive sync will reject the
+ * output commit.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_adaptive_sync_enabled(struct wlr_output_state *state,
 	bool enabled);
+/**
+ * Sets the render format for an output.
+ *
+ * The default value is DRM_FORMAT_XRGB8888.
+ *
+ * While high bit depth render formats are necessary for a monitor to receive
+ * useful high bit data, they do not guarantee it; a DRM_FORMAT_XBGR2101010
+ * buffer will only lead to sending 10-bpc image data to the monitor if
+ * hardware and software permit this.
+ *
+ * This only affects the format of the output buffer used when rendering using
+ * the output's own swapchain as with wlr_output_begin_render_pass(). It has no
+ * impact on the cursor buffer format, or on the formats supported for direct
+ * scan-out (see also wlr_output_state_set_buffer()).
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_render_format(struct wlr_output_state *state,
 	uint32_t format);
+/**
+ * Sets the subpixel layout hint for an output. Note that this is only a hint
+ * and may be ignored. The default value depends on the backend.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_subpixel(struct wlr_output_state *state,
 	enum wl_output_subpixel subpixel);
+/**
+ * Sets the buffer for an output. The buffer contains the contents of the
+ * screen. If the compositor wishes to present a new frame, they must commit
+ * with a buffer.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
 void wlr_output_state_set_buffer(struct wlr_output_state *state,
 	struct wlr_buffer *buffer);
+/**
+ * Sets the gamma table for an output. `r`, `g` and `b` are gamma ramps for
+ * red, green and blue. `size` is the length of the ramps and must not exceed
+ * the value returned by wlr_output_get_gamma_size().
+ *
+ * Providing zero-sized ramps resets the gamma table.
+ *
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
+bool wlr_output_state_set_gamma_lut(struct wlr_output_state *state,
+	size_t ramp_size, const uint16_t *r, const uint16_t *g, const uint16_t *b);
+/**
+ * Sets the damage region for an output. This is used as a hint to the backend
+ * and can be used to reduce power consumption or increase performance on some
+ * devices.
+ *
+ * This should be called in along with wlr_output_state_set_buffer().
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
+void wlr_output_state_set_damage(struct wlr_output_state *state,
+	const pixman_region32_t *damage);
+/**
+ * Set the output layers for an output. Output layers are used to try and take
+ * advantage of backend features that may reduce the amount of things that
+ * need to be composited.
+ *
+ * The array must be kept valid by the caller until wlr_output_state_finish()
+ * and all copies of the state have been finished as well.
+ * This state will be applied once wlr_output_commit_state() is called.
+ */
+void wlr_output_state_set_layers(struct wlr_output_state *state,
+	struct wlr_output_layer_state *layers, size_t layers_len);
+
+/**
+ * Copies the output state from src to dst. It is safe to then
+ * wlr_output_state_finish() src and have dst still be valid.
+ *
+ * Note: The lifetime of the output layers inside the state are not managed. It
+ * is the responsibility of the constructor of the output layers to make sure
+ * they remain valid for the output state and all copies made.
+ */
+bool wlr_output_state_copy(struct wlr_output_state *dst,
+	const struct wlr_output_state *src);
 
 
 /**
@@ -590,6 +716,13 @@ void wlr_output_state_set_buffer(struct wlr_output_state *state,
  */
 bool wlr_output_configure_primary_swapchain(struct wlr_output *output,
 	const struct wlr_output_state *state, struct wlr_swapchain **swapchain);
+/**
+ * Begin a render pass on this output.
+ *
+ * Same as wlr_output_attach_render(), but returns a struct wlr_render_pass.
+ */
+struct wlr_render_pass *wlr_output_begin_render_pass(struct wlr_output *output,
+	struct wlr_output_state *state, int *buffer_age, struct wlr_render_timer *timer);
 
 
 /**
